<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d poveznica';
$lang['%d associations'] = '%d poveznica';
$lang['%d album including'] = '%d skupina obuhvata ';
$lang['%d albums including'] = '%d skupine obuhvata ';
$lang['%d physical'] = '%d stvarna';
$lang['%d physical'] = '%d stvarnih';
$lang[' and %d virtual'] = ' i %d nestvrana';
$lang[' and %d virtual'] = ' i %d nestvarnih';
$lang['%d album moved'] = '%d skupina premještena';
$lang['%d albums moved'] = '%d skupina premješteno';
$lang['%d group'] = '%d grupa';
$lang['%d groups'] = '%d grupa';
$lang['%d member'] = '%d član';
$lang['%d members'] = '%d članova';
$lang['%d tag'] = '%d tag';
$lang['%d tags'] = '%d tagova';
$lang['%d user comment rejected'] = '%d korisnički komentar odbačen';
$lang['%d user comments rejected'] = '%d korisničkih komentara odbačeno';
$lang['%d user comment validated'] = '%d korisnički kometar odobren';
$lang['%d user comments validated'] = '%d korisničkih komentara odobreno';
$lang['%d user deleted'] = '%d korisnik izbrisan';
$lang['%d users deleted'] = '%d korisnika izbrisano';
$lang['%d user'] = '%d korisnik';
$lang['%d users'] = '%d korisnika';
$lang['%d waiting for validation'] = '%d čekanje na ovjeri';
$lang['Actions'] = 'Postupci';
$lang['Activate'] = 'Uključi';
$lang['Add/delete a permalink'] = 'Dodaj/izbriši stalnu poveznicu';
$lang['Add a tag'] = 'Dodaj';
$lang['Add a user'] = 'Dodaj korisnika';
$lang['Add group'] = 'Dodaj grupu';
$lang['Add'] = 'Dodaj';
$lang['Allow user registration'] = 'Odobri upis korisnika';
$lang['Apply to sub-albums'] = 'Primjeni na podskupine';
$lang['Associated'] = 'Povezanost';
$lang['Batch management'] = 'Slijedna uprava';
$lang['Caddie management'] = 'Uprava ladice';
$lang['Caddie'] = 'Ladica';
$lang['Albums authorized thanks to group associations'] = 'Skupine ovjerene zahvaljujući grupnoj povezanosti';
$lang['Album manual order was saved'] = 'Stvarni redoslijed skupina je pohranjen';
$lang['Check for upgrade failed for unknown reasons.'] = 'Provjera nadogradnje neuspješna iz nepoznatog razloga.';
$lang['Check for upgrade'] = 'Provjera nadogradnje';
$lang['Comments for all'] = 'Komentari za sve';
$lang['Current name'] = 'Trenutni naziv';
$lang['Database'] = 'Baza podataka';
$lang['Deactivate'] = 'Isključi';
$lang['Delete Representant'] = 'Izbriši Predstavnika';
$lang['Delete selected tags'] = 'Izbriši odabrane tagove';
$lang['Delete selected users'] = 'Izbriši odabrane korisnike';
$lang['Deletions'] = 'Brisanja';
$lang['Deny selected groups'] = 'Zabrani odabrane grupe';
$lang['Deny selected users'] = 'Zabrani odabrane korisnike';
$lang['Description'] = 'Opis';
$lang['Display options'] = 'Mogućnosti prikaza';
$lang['Dissociated'] = 'Odvojeno';
$lang['Does not represent'] = 'Ne predstavlja';
$lang['Edit selected tags'] = 'Uredi odabrane tagove';
$lang['Edit tags'] = 'Uredi tagove';
$lang['Email admins when a new user registers'] = 'E-mail upraviteljima pri upisu novih korisnika';
$lang['Email admins when a valid comment is entered'] = 'E-mail upraviteljima pri upisu novih komentara';
$lang['Email admins when a comment requires validation'] = 'Email upraviteljima kada komentar treba ovjeru';
$lang['Environment'] = 'Okruženje';
$lang['Form'] = 'Oblik';
$lang['Gallery title'] = 'Naziv galerije';
$lang['Grant selected groups'] = 'Ovlasti odabrane grupe';
$lang['Grant selected users'] = 'Ovlasti odabrane korisnike';
$lang['Group name'] = 'Naziv grupe';
$lang['Groups'] = 'Grupa';
$lang['Guests'] = 'Gostiju';
$lang['History'] = 'Povijest';
$lang['Informations'] = 'Obavijesti';
$lang['Install'] = 'Ugradi';
$lang['Link all album photos to a new album'] = 'Poveži sve stavke skupine sa novom skupinom';
$lang['Link all album photos to some existing albums'] = 'Poveži sve stavke skupine sa nekom postojećom skupinom';
$lang['Linked albums'] = 'Povezane skupine';
$lang['Lock gallery'] = 'Zaključaj galeriju';
$lang['Maintenance'] = 'Održavanje';
$lang['Edit album permissions'] = 'Upravljanje ovlastima za skupinu';
$lang['Manage permissions for group "%s"'] = 'Upravljanje ovlastima za grupu "%s"';
$lang['Manage permissions for user "%s"'] = 'Upravljanje ovlastima za korisnika "%s"';
$lang['Manage tags'] = 'Upravljanje tagovima';
$lang['Members'] = 'Članovi';
$lang['Metadata synchronized from file'] = 'Usklađivanje meta podataka iz zapisa';
$lang['Move albums'] = 'Premjesti skupine';
$lang['Move'] = 'Premjesti';
$lang['Name'] = 'Naziv';
$lang['New name'] = 'Novi naziv';
$lang['New parent album'] = 'Nova nadređena skupina';
$lang['New tag'] = 'Novi tag';
$lang['Number of comments per page'] = 'Broj komentara po stranici';
$lang['Number of rates'] = 'Broj ocjena';
$lang['Number of thumbnails to create'] = 'broj poveznih sličica za izradu';
$lang['Only private albums are listed'] = 'Samo osobne skupine su ispisane';
$lang['Operating system'] = 'Operativni sustav';
$lang['Options'] = 'Mogućnosti';
$lang['Other private albums'] = 'Ostale osobne skupine';
$lang['Page banner'] = 'Baner stranice';
$lang['Parent album'] = 'Nadređena skupina';
$lang['Permalink'] = 'Stalna poveznica';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Stalna poveznica %s je prethodno korištena od skupine %s. Prvo je izbrišite iz starih zapisa';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'Stalna poveznica mora biti sastavljena od znakova a-z, A-Z, 0-9, "-", "_" ili "/". Ne smije biti brojčana vrijednost ili počinjati brojem pa znakom "-"';
$lang['Permalink %s is already used by album %s'] = 'Stalnu poveznicu %s već koristi skupina %s';
$lang['Permalink history'] = 'Povijest stalnih poveznica';
$lang['Permalinks'] = 'Stalne poveznice';
$lang['Permission denied'] = 'Dozvola uskraćena';
$lang['Permission granted thanks to a group'] = 'Dozvola odobrena zahvaljujući grupi';
$lang['Permission granted'] = 'Dozvola odobrena';
$lang['Photo informations updated'] = 'Podaci o slikama obnovljeni';
$lang['Plugins'] = 'Dodaci';
$lang['Position'] = 'Položaj';
$lang['Preferences'] = 'Postavke';
$lang['Properties'] = 'Svojstva';
$lang['Random photo'] = 'Slika slučajnog odabira';
$lang['Rate date'] = 'Nadnevak ocjene';
$lang['Rating by guests'] = 'Ocjene gostiju';
$lang['Rating'] = 'Ocjenjivanje';
$lang['Reject'] = 'Odbaci';
$lang['Representant'] = 'Predstavnik';
$lang['Representation of albums'] = 'Predstavljanje skupina';
$lang['Representative'] = 'Predstavljeno';
$lang['Represents'] = 'Predstavlja';
$lang['Save order'] = 'Redoslijed pohrane';
$lang['Save to permalink history'] = 'Pohrani u povjest stalnih poveznica';
$lang['Select at least one album'] = 'Odaberite najmanje jednu skupinu';
$lang['Select at least one photo'] = 'Odaberite najmanje jednu sliku';
$lang['Select at least one user'] = 'Odaberite najmanje jednog korisnika';
$lang['Show info'] = 'Prikaz podataka';
$lang['Site manager'] = 'Upravnik galerije';
$lang['Status'] = 'Stanje';
$lang['Statistics'] = 'Statistika';
$lang['Storage album'] = 'Skupina pohrane';
$lang['Sum of rates'] = 'Zbroj ocjena';
$lang['Tag "%s" already exists'] = 'Tag "%s" već postoji';
$lang['Tag "%s" was added'] = 'Tag "%s" dodan';
$lang['Tag selection'] = 'Odabir tagova';
$lang['The %d following tags were deleted'] = 'Slijedeći %d tagovi su izbrisani';
$lang['Unable to check for upgrade.'] = 'Ne mogu provjeriti za nadogradnju.';
$lang['Uninstall'] = 'Ukloni';
$lang['Use the default photo sort order (defined in the configuration file)']='Koristi pretpostavljeni redoslijed slaganja slika (određeno u zapisu postave)';
$lang['User comments validation'] = 'Ovjera korisničkih komentara';
$lang['Users'] = 'Korisnici';
$lang['Validate'] = 'Ovjeri';
$lang['Validation'] = 'Ovjera';
$lang['Version'] = 'Inačica';
$lang['Virtual albums to move'] = 'Nestvarne skupine za premještaj';
$lang['Virtual album name'] = 'Naziv nestvarne skupine';
$lang['Webmaster cannot be deleted'] = 'Webmaster ne može biti izbrisan';
$lang['You are running on development sources, no check possible.'] = 'Vi koristite razvojni izvorni kod, provjera nemoguća.';
$lang['You cannot delete your account'] = "Ne možete izbrisati svoj račun";
$lang['You cannot move an album in its own sub album'] = 'Ne možete premjestiti skupinu u njenu vlastitu podskupinu';
$lang['You need to confirm deletion'] = 'trebate potvrditi brisanje';
$lang['add tags'] = 'dodaj tagove';
$lang['Associate to album'] = 'poveži sa skupinom';
$lang['associate to group'] = 'poveži sa grupom';
$lang['Authorized'] = 'Ovlašteno';
$lang['Add a virtual album'] = 'Dodaj nestvarnu skupinu';
$lang['Authorize users to add comments on selected albums'] = 'Ovlastite korisnike za davanje komentara u odabranim skupinama';
$lang['The name of an album must not be empty'] = 'Naziv skupine ne bi trebao biti prazan';
$lang['Lock albums'] = 'Zaključaj skupine';
$lang['Private'] = 'Osobna skupina';
$lang['Public'] = 'Javna skupina';
$lang['Find a new representant by random'] = 'Izbor novog predstavnika slučajnim odabirom';
$lang['Public / Private'] = 'Javno / Osobno';
$lang['Manage authorizations for selected albums'] = 'Upravljanje ovlastima za odabrane skupine';
$lang['Virtual album added'] = 'Nestvarna skupina dodana';
$lang['Virtual album deleted'] = 'Nestvarna skupina izbrisana';
$lang['Access type'] = 'Vrsta pristupa';
$lang['Comments'] = 'Komentari';
$lang['Information data registered in database'] = 'Podaci upisani u bazu podataka';
$lang['Default display'] = 'Pretpostavljeni prikaz';
$lang['The gallery URL is not valid.'] = 'URL galerije nije valjan.';
$lang['Main'] = 'Glavno';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Broj komentara po stranici mora biti između 5 i 50 uključivo.';
$lang['Configuration'] = 'Postavljanje';
$lang['confirm'] = 'potvrdi';
$lang['Date'] = 'Nadnevak';
$lang['delete album'] = 'izbriši skupinu';
$lang['Dissociate from album'] = 'odspoji od skupine';
$lang['dissociate from group'] = 'odspoji od grupe';
$lang['edit album permissions'] = 'uredi ovlasti skupine';
$lang['Album updated successfully'] = 'Podaci skupine uspješno obnovljeni.';
$lang['photos per page'] = 'stavaka po stranici';
$lang['High definition enabled'] = 'Visoka razlučljivost omogućena';
$lang['File'] = 'Zapis';
$lang['Filesize'] = 'Veličina zapisa';
$lang['first photo added on %s'] = 'prva stavka dodana %s';
$lang['Forbidden'] = 'Zabranjeno';
$lang['global mode'] = 'sveopći način';
$lang['group "%s" added'] = 'grupa "%s" dodana';
$lang['group "%s" deleted'] = 'grupa "%s" izbrisana';
$lang['group "%s" updated'] = 'grupa "%s" obnovljena';
$lang['group'] = 'grupa';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Naziv grupe ne može sadržavati  " ili \' ili biti prazan.';
$lang['This name is already used by another group.'] = 'Ovaj naziv već koristi druga grupa.';
$lang['High definition'] = 'Visoka razlučljivost';
$lang['jump to album'] = 'skok u skupina';
$lang['jump to photo'] = 'skok na sliku';
$lang['leave'] = 'ostavi';
$lang['Lock'] = 'Zaključaj';
$lang['Locked'] = 'Zaključanp';
$lang['manage album photos'] = 'upravljanje stavkama skupine';
$lang['manage sub-albums'] = 'upravljanje podskupinama';
$lang['Manage'] = 'Uprava';
$lang['maximum height'] = 'najveća visina';
$lang['maximum width'] = 'najveća širina';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Predviđeno vrijeme za popis korisnika za slanje poruka je ograničeno. Ostali korisnici nisu izlistani.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Vrijeme za slanje poruke je ograničeno. Ostale poruke su preskočene.';
$lang['To send ?'] = 'Poslati ?';
$lang['Last send'] = 'Zadnje poslano';
$lang['email'] = 'e-mail';
$lang['User'] = 'Korisnik';
$lang['Complementary mail content'] = 'Poptpuni sadržaj e-mail poruke';
$lang['See you soon,'] = 'Vidimo se uskoro,';
$lang['Go to'] = 'Idi na ';
$lang['Hello'] = 'Pozdrav ';
$lang['New photos were added'] = 'Nove stavke su dodane ';
$lang['on'] = ' na ';
$lang['between'] = 'između ';
$lang['and'] = ' i ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Webmaster vas je pretlatio na primanje e-mail obavijesti.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Pretplatili ste se na primanje e-mail obavijesti.';
$lang['To subscribe'] = 'Pretplata';
$lang['If you encounter problems or have any question, please send a message to'] = 'Ukoliko ste naišli na probleme ili imate pitanja, molimo pošaljite poruku za ';
$lang['[NBM] Problems or questions'] = '[NBM] Problemi ili pitanja';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Webmaster vas je uklonio sa popisa za primanje e-mail obavijesti.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Uklonili ste se sa popisa za primanje e-mail obavijesti.';
$lang[', click on'] = ', kliknite na ';
$lang['To unsubscribe'] = 'Za uklanjanje';
$lang['With blank value, gallery title will be used'] = 'Sa praznim poljem, koristiti će se naziv galerijeg';
$lang['Notification'] = 'Obavijest';
$lang['Error when sending email to %s [%s].'] = 'Greška prilikom slanja e-mail poruke za %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Poruka poslana za %s [%s].';
$lang['%d mail was sent.'] = '%d poruka poslana.';
$lang['%d mails were sent.'] = '%d poruke poslane.';
$lang['%d mail was not sent.'] = '%d poruka nije poslane.';
$lang['%d mails were not sent.'] = '%d poruke nisu poslane.';
$lang['No mail to send.'] = 'Nema poruke za slanje.';
$lang['There is no available subscribers to mail.'] = 'Nema dostupnih primatelja za slanje poruka.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Pretplatnici mogu biti izlistani (dostupni) samo ako ima novih stavki za obavijest.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'U svakom slučaju samo webmaster može pristupiti ovoj ploči a nikad upravitelji.';
$lang['No user to send notifications by mail.'] = 'Nema korisnika za slanje e-mail obavijesti.';
$lang['New photos added'] = 'Nove stavke dodane';
$lang['Subscribe to notification by mail'] = 'Pretplatite se za e-mail obavijesti';
$lang['Unsubscribe from notification by mail'] = 'Uklonite se iz sustava primanja e-mail obavijesti';
$lang['Parameter'] = 'Stavka';
$lang['Continue processing treatment'] = 'Nastavi obradu postupka';
$lang['Complementary mail content'] = 'Cjelokupni sadržaj poruke';
$lang['Add detailed content'] = 'Dodaj cjeli sadržaj';
$lang['Send mail as'] = 'Pošalji poruku kao ';
$lang['Send mail to users'] = 'Pošalji poruku korisnicima';
$lang['Send'] = 'Pošalji';
$lang['Options'] = 'Mogućnosti';
$lang['Subscribed'] = 'Pretplaćen';
$lang['Subscribe'] = 'Pretplatite se';
$lang['Parameters'] = 'Stavke';
$lang['Select recipients'] = 'Odaberite primatelje';
$lang['Subscribe/unsubscribe users'] = 'Pretplati/poništi pretplatu korosnika';
$lang['Unsubscribed'] = 'Pretplata poništena';
$lang['%d parameter was updated.'] = '%d stavka je obnovljena.';
$lang['%d parameters were updated.'] = '%d stavke su poništene.';
$lang['%d user was not updated.'] = '%d korisnik nije obnovljen.';
$lang['%d users were not updated.'] = '%d korisnici nisu obnovljeni.';
$lang['User %s [%s] was removed from the subscription list.'] = 'User %s [%s] je uklonjen iz popisa pretplatnika.';
$lang['User %s [%s] was added to the subscription list.'] = 'User %s [%s] je dodan na popis pretplatnika.';
$lang['%d user was updated.'] = '%d korisnik je obnovljen.';
$lang['%d users were updated.'] = '%d korisnici su obnovljeni.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'Korisnik %s [%s] nije uklonjen iz popisa pretplatnika.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Korisnik %s [%s] nije dodan na popis pretplatnika.';
$lang['User %s [%s] added.'] = 'Korisnik %s [%s] dodan.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Upozorenje: pretplata ili ukidanje pretplate će poslati e-mail poruke korisnicima';
$lang['Send mail on HTML format'] = 'Pošalji poruku u HTML obliku';
$lang['Include display of recent photos grouped by dates'] = 'Uključi prikaz nedavnih slika složenih po nadnevcima';
$lang['Available only with HTML format'] = 'Dostupno samo u HTML obliku';
$lang['no write access'] = 'nema dozvole upisa';
$lang['Permissions'] = 'Dozvole';
$lang['private'] = 'osobno';
$lang['public'] = 'javno';
$lang['Purge never used notification feeds'] = 'Isprazni nikad korištene obavijesne izvore';
$lang['Purge sessions'] = 'Isprazni sjednice';
$lang['randomly represented'] = 'predstavljen slučajnim odabirom';
$lang['registration date'] = 'nadnevak upisa';
$lang['clean'] = 'čisto';
$lang['remove remote listing.xml file'] = 'ukloni udaljeni listing.xml zapis';
$lang['generate listing'] = 'izradi popis';
$lang['generate file listing.xml on remote site'] = 'izradi listing.xml zapis na udaljenom mjestu';
$lang['Create this site'] = 'Izgradi ovo mjesto';
$lang['A local listing.xml file has been found for'] = 'Mjesni listing.xml zapis je pronađen za ';
$lang['read local listing.xml and update'] = 'čitam mjesni listing.xml i obnavljam';
$lang['test'] = 'proba';
$lang['test this remote site'] = 'isprobajte ovo udaljeno mjesto';
$lang['remove tags'] = 'ukloni tagove';
$lang['Repair and optimize database'] = 'Popravi i ugodi bazu podataka';
$lang['selection'] = 'odabir';
$lang['set to'] = 'postavljeno na';
$lang['singly represented'] = 'jednoznačno predstavljeno';
$lang['This site already exists'] = 'Ovo mjesto već postoji';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Izradi novo mjesto : (odreite njegov URL za izradu create_listing_file.php)';
$lang['created'] = 'izrađeno';
$lang['delete'] = 'izbriši';
$lang['delete this site and all its attached elements'] = 'izbriši ovo mjesto i sve njegove pridodane stavke';
$lang['an error happened'] = 'došlo je do greške';
$lang['file create_listing_file.php on remote site was not found'] = 'zapis create_listing_file.php na udaljenom mjestu nije pronađen';
$lang['Local'] = 'Mjesno';
$lang['Remote'] = 'Udaljeno';
$lang['synchronize'] = 'uskladi';
$lang['update the database from files'] = 'obnovi bazu podataka pomoću zapisa';
$lang['status'] = 'stanje';
$lang['Directory'] = 'Mapa';
$lang['sub-albums'] = 'podskupine';
$lang['synchronize metadata'] = 'uskladi meta podatke';
$lang['target'] = 'odredište';
$lang['Thumbnail'] = 'Povezne sličice';
$lang['title'] = 'naslov';
$lang['Album list management'] = 'Upravljanje skupinama';
$lang['Piwigo configuration'] = 'Piwigo postave';
$lang['Edit album'] = 'Uredi skupinu';
$lang['Group management'] = 'Upravljanje grupama';
$lang['User list'] = 'Popis korisnika';
$lang['Edit photo information'] = 'Promjena podataka o slici';
$lang['Thumbnail creation'] = 'Izrada poveznij sličica';
$lang['Database synchronization with files'] = 'Usklađivanje baze podataka sa zapisima';
$lang['all'] = 'sve';
$lang['photos without thumbnail (jpeg and png only)'] = 'slike bez poveznih sličica (samo jpeg i png)';
$lang['height must be a number superior to'] = 'visina mora biti broj veći od ';
$lang['width must be a number superior to'] = 'širina mora biti broj veći od';
$lang['for the file format'] = 'za zapisni oblik';
$lang['No missing thumbnail'] = 'Nema nedostajućih poveznih sličica';
$lang['Photo unreachable or no support'] = 'Slika nedohvatna ili bez podrške';
$lang['GD version'] = 'GD inačica';
$lang['Miniaturization parameters'] = 'Postavke umanjivanja';
$lang['generated in'] = 'izrađena u';
$lang['Results of miniaturization'] = 'ishodi umanjivanja';
$lang['General statistics'] = 'Glavna statistika';
$lang['max time'] = 'najveće vrijeme';
$lang['average time'] = 'prosječno vrijeme';
$lang['min time'] = 'najmanje vrijeme';
$lang['number of miniaturized photos'] = 'broj umanjenih slika';
$lang['total time'] = 'sveukupno vrijeme';
$lang['for this file format'] = 'za ovu vrstu zapisa';
$lang['unit mode'] = 'jedinični način';
$lang['Unlocked'] = 'Otključano';
$lang['unset'] = 'razdešeno';
$lang['Update albums informations'] = 'Obnovi podatke o skupinama';
$lang['Update photos information'] = 'Obnovi podatke o slikama';
$lang['Synchronize'] = 'Uskladi';
$lang['reduce to single existing albums'] = 'suzi na jednu postojeću skupinu-e';
$lang['Choose an option'] = 'Izaberite mogućnost';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'najopširniji mogući prikaz podataka (dodane skupine i stavke, izbrisane  skupine i stavke)';
$lang['Piwigo version differs on the remote site'] = 'Piwigo inačica na udaljenom mjestu se razlikuje';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'Inačica create_listing_file.php na udaljenom mjestu i Piwigo-u mora biti jednaka';
$lang['listing.xml file was not found'] = 'listing.xml zapis nije pronađen';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'listing.xml zapis nije pronađen na udaljenom mjestu. Ovaj zapis se izrađuje odabirom "izradi popis" mogućnosti u Upravi mjesta';
$lang['Error list'] = 'Greška popisa';
$lang['Errors caption'] = 'Zaglavlja grešaka';
$lang['Detailed informations'] = 'Podrobnije obavjesti';
$lang['File/directory read error'] = 'Greška čitanja zapisa/mape';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Zapisu ili mapi se ne može pristupiti (ne postoji ili je pristup zabranjen)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'tip slikovnog zapisa zahtjeva poveznu sličicu. Povezna sličica mora biti prisutna u podmapi "thumbnail" mape skupine. Naziv povezne sličice mora počinjati sa pretpostavljenim predznakom i nastavak mora biti jedan od popisanih :';
$lang['missing thumbnail'] = 'nedostajuće povezne sličice';
$lang['albums deleted in the database'] = 'skupine izbrisane iz baze podataka';
$lang['photos deleted from the database'] = 'stavke izbrisane iz baze podataka';
$lang['photos candidates for metadata synchronization'] = 'slika kandidata za usklađivanje meta podataka';
$lang['photos informations synchronized with files metadata'] = 'podataka stavaka usklađeno sa meta podacima zapisa';
$lang['errors during synchronization'] = 'grešaka tijekom usklađivanja';
$lang['albums added in the database'] = 'skupina dodano u bazu podataka';
$lang['photos added in the database'] = 'stavaka dodano u bazu podataka';
$lang['photos updated in the database'] = 'stavaka obnovljeno u bazi podataka';
$lang['Search for new images in the directories'] = 'Pretraživanje novih slika u mapama';
$lang['added'] = 'dodano';
$lang['deleted'] = 'izbrisano';
$lang['Metadata synchronization results'] = 'Ishodi usklađivanja meta podataka';
$lang['only perform a simulation (no change in database will be made)'] = 'izvrši samo oponašanje (nema promjena u bazi podataka)';
$lang['[Simulation]'] = '[Oponašanje]';
$lang['Simulation'] = 'Oponašanje';
$lang['directories + files'] = 'mape + zapise';
$lang['only directories'] = 'samo mape';
$lang['synchronize files structure with database'] = 'uskladi sastav zapisa sa bazom podataka';
$lang['synchronize files metadata with database photos informations'] = 'uskladi meta podatke zapisa sa podacima stavki baze podataka';
$lang['even already synchronized photos'] = 'čak i već usklađene stavke';
$lang['Used metadata'] = 'Korišteni meta podaci';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Nazivi mapa i zapisa moraju biti sastavljeni od slova, brojva, "-", "_" ili "."';
$lang['wrong filename'] = 'krivi naziv zapisa';
$lang['Upload'] = 'Prebaci';
$lang['user "%s" added'] = 'korisnik "%s" dodan';
$lang['User status'] = 'Stanje korisnika';
$lang['user_status_admin'] = 'Upravnik';
$lang['user_status_generic'] = 'Općenit';
$lang['user_status_guest'] = 'Gost';
$lang['user_status_normal'] = 'Korisnik';
$lang['user_status_webmaster'] = 'Webmaster';
$lang['Virtual album'] = 'Nestvarna skupina';
$lang['Waiting'] = 'Čekanje';
$lang['default'] = 'pretpostavljeno';
$lang['Toggle \'default group\' property'] = 'Promijeni \'pretpostavljena grupa\' svojstva';
$lang['Advanced features'] = 'Napredne mogućnosti';
$lang['Specials'] = 'Posebnosti';
$lang['Overall'] = 'Sveukupno';
$lang['Year'] = 'Godina';
$lang['Month'] = 'Mjesec';
$lang['Day'] = 'Dan';
$lang['Pages seen'] = 'Stranica viđeno';
$lang['Time'] = 'Vrijeme';
$lang['IP'] = 'IP';
$lang['Element'] = 'Stavka';
$lang['Section'] = 'Odjeljak';
$lang['Tags'] = 'Tagovi';
$lang['Save page visits by guests'] = 'Pohrani posjete stranicama po gostima';
$lang['Save page visits by users'] = 'Pohrani posjete stranicama po korisnicima';
$lang['Save page visits by administrators'] = 'Pohrani posjete stranicama upraviteljima';
$lang['An information email was sent to group "%s"'] = 'Obavijesna e-mail poruka je poslana grupi "%s';
$lang['Send an information email to group members'] = 'Pošalji obavijesni e-mail članovima grupe';
$lang['Group'] = 'Grupa';
$lang['[%s] Visit album %s'] = '[%s] Dođite i pogledajte skupinu %s';
$lang['Hello,'] = 'Pozdrav,';
$lang['See you soon.'] = 'Do skorog viđenja.';
$lang['Discover album:'] = 'Dođite i otkrijte skupinu:';
$lang['Mail content'] = 'sadržaj e-mail poruke';
$lang['none'] = 'ni jedan';
$lang['high'] = 'visoko';
$lang['other'] = 'ostalo';
$lang['Element type'] = 'Tip stavke';
$lang['Image id'] = 'ID slike';
$lang['Summary'] = 'Zbirno';
$lang['%d line filtered'] = '%d linija pročišćena';
$lang['%d lines filtered'] = '%d linija pročišćeno';
$lang['%d guest'] = '%d gost';
$lang['%d guests'] = '%d gostiju';
$lang['Hour'] = 'Sat';
$lang['guest'] = 'gost';
$lang['default values'] = 'pretpostavljene vrijednosti';
$lang['High filesize'] = 'Visoka veličina zapisa';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = 'Gost ne može biti izbrisan';
$lang['Default user cannot be deleted'] = 'Pretpostavljeni korisnik ne može biti izbrisan';
$lang['Purge history detail'] = 'Isprazni povijesne pojedinosti';
$lang['Purge history summary'] = 'Isprazni povijesni zbir';
$lang['Check integrity'] = 'Provjera cjelovitosti';
$lang['Anomaly'] = 'Nepravilnost';
$lang['Correction'] = 'Ispravak';
$lang['Automatic correction'] = 'Samostalno ispravljanje';
$lang['Impossible automatic correction'] = 'Samostalno ispravljanje nemoguće';
$lang['Correction applied with success'] = 'Ispravka uspješno ugrađena';
$lang['Correction applied with error'] = 'Ispravka ugrađena s greškom';
$lang['%d anomaly has been detected.'] = '%d nepravilnost je otkrivena.';
$lang['%d anomalies have been detected.'] = '%d nepravilnosti su otkrivene.';
$lang['%d anomaly has been corrected.'] = '%d nepravilnost je ispravljena.';
$lang['%d anomalies have been detected corrected.'] = '%d nepravilnosti je ispravljeno.';
$lang['%d anomaly has not been corrected.'] = '%d nepravilnost nije ispravljena.';
$lang['%d anomalies have not been corrected.'] = '%d nepravilnosti nije ispravljeno.';
$lang['Go to %s or %s for more informations'] = 'Idite na %s ili %s za više pojedinosti';
$lang['the forum'] = 'forum';
$lang['the wiki'] = 'wiki';
$lang['%s value is not correct file because exif are not supported'] = '%s vrijednost nije valjani zapis jer exif nije podržan';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s mora biti postavljeno na false u config_local.inc.php file';
$lang['Main "guest" user does not exist'] = 'Glavni "guest" korisnik ne postoji';
$lang['Main "guest" user status is incorrect'] = 'Stanje glavnog "guest" korisnika je neispravno';
$lang['Default user does not exist'] = 'Pretpostavljeni korisnik ne postojit';
$lang['Main "webmaster" user does not exist'] = 'Glavni "webmaster" korisnik ne postoji';
$lang['Main "webmaster" user status is incorrect'] = 'Stanje glavnog "webmaster" korisnika je neispravno';
$lang['User "%s" created with "%s" like password'] = 'Korisnik "%s" izrađen sa "%s" kao zaporkom';
$lang['Status of user "%s" updated'] = 'Stanje korisnika "%s" obnovljeno';
$lang['add new photos to caddie'] = 'dodaj nove stavke u ladicu';
// --------- Starting below: New or revised $lang ---- from Butterfly
$lang['No display'] = 'Bez prikaza';
$lang['Classic display'] = 'Klasični prikaz';
$lang['Hoverbox display'] = 'Prikaz lebdećim prozorom';
$lang['Mail address is obligatory for all users'] = 'E-mail adresa je obavezna za sve korisnike';
$lang['Minimum privacy level'] = 'Najniža razina privatnosti';
$lang['Privacy level'] = 'Razina privatnosti';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Poznanici';
$lang['Level 2'] = 'Prijatelji';
$lang['Level 4'] = 'Obitelj';
$lang['Level 8'] = 'Upravnici';
$lang['Reinitialize check integrity'] = 'Ponovi provjeru cjelovitosti';
$lang['Check all'] = 'Označi sve';
$lang['Uncheck all'] = 'Odznači sve';
$lang['Check automatic corrections'] = 'Označi samoispravke';
$lang['Apply selected corrections'] = 'Primjeni odabrane ispravke';
$lang['Ignore selected anomalies'] = 'Zanemari odabrane nepravilnosti';
$lang['Refresh'] = 'Osvježi';
$lang['The anomaly will be ignored until next application version'] = 'Nepravilnost će se zanemariti do slijedeće inačice galerije';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Ispravak nepravilnosti će poništiti činjenicu da je zanemarena';
$lang['%d anomaly has been ignored.'] = '%d nepravilnost je zanemarena.';
$lang['%d anomalies have been ignored.'] = '%d nepravilnosti su zanemarene.';
$lang['Plugins which need upgrade'] = 'Dodaci koji trebaju nadogradnju';
$lang['Plugin list'] = 'Popis dodataka';
$lang['Check for updates'] = 'Provjera nadogradnji';
$lang['Other plugins'] = 'Ostali dodaci';
$lang['Last revisions'] = 'Zadnja izdanja';
$lang['Delete'] = 'Izbriši';
$lang['Are you sure you want to delete this plugin?'] = 'Sigurno želite ukloniti ovaj dodatak?';
$lang['Are you sure you want to install this plugin?'] = 'Sigurno želite ugraditi ovaj dodatak?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Sigurno želite ugraditi ovaj dodatak? Morate ovjeriti ako ova inačica ne treba uklanjanje.';
$lang['%s has been successfully upgraded.'] = '%s je uspješno obnovljen.';
$lang['Plugin has been successfully copied'] = 'Dodatak je uspješno preslikan';
$lang['You might go to plugin list to install and activate it.'] = 'Možete ići na popis dodataka za ugradbu i pokretanje.';
$lang['Can\'t create temporary file.'] = 'Ne mogu napraviti privremeni zapis.';
$lang['Can\'t download archive.'] = 'Ne mogu preuzeti zapis.';
$lang['Can\'t read or extract archive.'] = 'Ne mogu očitati ili izlučiti zapis.';
$lang['An error occured during extraction (%s).'] = 'Došlo je do greške prilikom izlučivanja (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Provjerite "plugins" mapu i dozvole podmapa (CHMOD).';
$lang['Can\'t connect to server.'] = 'Ne mogu se povezati na poslužitelj.';
$lang['Purge compiled templates'] = 'Isprazni obrađene predloške';
$lang['ACCESS_0'] = 'Slobodan pristup';
$lang['ACCESS_1'] = 'Pristup svima';
$lang['ACCESS_2'] = 'Pristup pretplatnicima';
$lang['ACCESS_3'] = 'Pristup upraviteljima';
$lang['ACCESS_4'] = 'Pristup webmaster-ima';
$lang['ACCESS_5'] = 'Bez pristupa';
$lang['Support'] = 'Podrška';
$lang['Documentation'] = 'Dokumentacija';
$lang['A new version of Piwigo is available.'] = 'Nova Piwigo inačica je dostupna.';
$lang['Piwigo Administration'] = 'Piwigo Uprava';
$lang['Piwigo version'] = 'Piwigo inačica';
$lang['You are running the latest version of Piwigo.'] = 'Koristite najnoviju inačicu Piwigo-a.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'Inačica od %s [%s] postavljene nije sukladna potrebnoj inačici [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'trebate nadograditi vaš sustav da biste imali sve pogodnosti u protivnom sustav neće raditi uredno ili uopće neće raditi';
$lang['Deleted on'] = 'Izbrisan na';
$lang['Last hit'] =  'Zadnji posjet';
$lang['GD library is missing'] = 'Nedostaje GD biblioteka';
$lang['Templates'] = 'Predlošci';
$lang['Extend for templates'] = 'Proširenje za predloške';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] =
 'Zamjena izvornih predložaka prilagođenima iz podmape template-extension';
$lang['Replacers (customized templates)'] = 'Zamjene (prilagođeni predlošci)';
$lang['Original templates'] = 'Izvorni predlošci';
$lang['Optional URL keyword'] = 'Izborna URL ključna riječ';
$lang['Templates configuration has been recorded.'] = 'Postava predložaka je pohranjena.';
$lang['All optimizations have been successfully completed.'] = 'Sva poboljšanja su uspješno dovršena.';
$lang['Optimizations have been completed with some errors.'] = 'Poboljšanja su izvršena uz neke greške.';
$lang['Modify information'] = 'Promijeni podatak';
$lang['edit album'] = 'uredi podatke o skupini';
$lang['nothing'] = 'ništa';
$lang['overrides existing values with empty ones'] = 'prekucava postojeće vrijednosti praznim poljima';
$lang['manage photo ranks'] = 'upravljanje poretkom slika';
$lang['Manage photo ranks'] = 'Uprava poretkom';
$lang['Edit ranks'] = 'Uredi poredak';
$lang['No photo in this album'] = 'Nema stavke u ovoj skupini';
$lang['Images manual order was saved'] = 'Pohranjen je izvorni redoslijed slika';
$lang['ranks'] = 'poretci';
$lang['Drag to re-order'] = 'Povuci za preslagivanje';
$lang['Quick Local Synchronization'] = 'Brzo Mjesno Usklađivanje';
$lang['No photo can be deleted'] = 'Nema slike koja se može brisati';
$lang['Delete selected photos'] = 'Briši odabrane slike';
$lang['%d photo was deleted'] = '%d slika je izbrisana';
$lang['%d photos were deleted'] = '%d slike su izbrisane';
$lang['Downloads'] = 'Preuzimanja';
$lang['Released on'] = 'Objavljeno dana';
$lang['Number of downloads'] = 'Broj preuzimanja';
// --------- Starting below: New or revised $lang ---- from Colibri
$lang['Piwigo Announcements Newsletter'] = 'Piwigo Announcements e-Novine';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Ostanite u vezi sa projektom, pretplatite se na Piwigo Announcement e-Novine. Primati ćete e-mail poruke po izlasku novih inačica (ponekad sa sigurnosnim zakrpama, važno je znati da su dostupne i treba ih što prije ugraditi) te o svim važnijim zbivanjima i događanjima u vezi sa projektom. Svega par e-mail poruka godišnje.';
$lang['Subscribe %s'] = 'Pretplatite %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Pretplatite %s na Piwigo English Announcements e-Novine';
$lang['Purge search history'] = 'Pročisti povijest pretraživanja';
$lang['Hide'] = 'Sakrij';
// piwigo 2.1
$lang['Operation in progress'] = 'Obrada postupka.';
$lang['Please wait...'] = 'Sačekajte molim...';
$lang['Password is missing. Please enter the password.'] = 'Nedostaje zaporka. Molimo unesite zaporku.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Nedostaje potvrda zaporke. Molimo potvrdite odabranu zaporku.';
$lang['Password confirmation error.'] = 'Greška potvrde zaporke.';
$lang['Allow users to edit their own comments'] = 'Dozvoliti korisnicima uređivanje vlastitih komentara';
$lang['Allow users to delete their own comments'] = 'Dozvoliti korisnicima brisanje vlastitih komentara';
$lang['Email administrators when a comment is modified'] = 'E-mail poruka upravnicima kada je komentar promijenjen';
$lang['Email administrators when a comment is deleted'] = 'E-mail poruka upravnicima kada je komentar izbrisan';
$lang['Cannot delete the old permalink !'] = 'Stare stalne poveznice ne mogu se brisati!';
$lang['Hit'] = 'Posjeta';
$lang['Tools'] = 'Alati';
$lang['Photos'] = 'Slike';
$lang['Themes'] = 'Teme';
$lang['Instructions to use Piwigo'] = 'Upute za korištenje Piwigo-a';
$lang['Installed Themes'] = 'Ugrađene Teme';
$lang['Add New Theme'] = 'Dodaj novu temu';
$lang['Forbid this theme to users'] = 'Zabrani ovu temu korisnicima';
$lang['Set as default theme for unregistered and new users'] = 'Postavi za pretpostavljenu temu za nepoznate i nove korisnike';
$lang['unknown'] = 'nepoznat';
$lang['Upload Photos'] = 'Prebaci Slike';
$lang['Drop into album'] = 'Spusti u skupinu';
$lang['+ Add an upload box'] = '+ Dodaj kutiju prebacivanja';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Izradi "%s" mapu u korijenu vaše Piwigo galerije';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Dozvoli pravo upisa (chmod 777) za "%s" mapu u korijenu Piwigo galerije';
$lang['existing album'] = 'postojeća skupina';
$lang['create a new album'] = 'stvori novu skupinu';
$lang['Album name'] = 'Naziv skupine';
$lang['Album "%s" has been added'] = 'Skupina "%s" je dodana';
$lang['Uploaded Photos'] = 'Prebačene Slike';
$lang['%d photos uploaded'] = '%d slika prebačeno';
$lang['Privacy level set to "%s"'] = 'Razina privatnosti postavljena na "%s"';
$lang['Album "%s" now contains %d photos'] = 'Skupina "%s" sada sadržava %d slika';
$lang['Manage this set of %d photos'] = 'Upravljanje ovim skupom od %d slika';
$lang['Select files'] = 'Odaberi zapise';
$lang['Everybody'] = 'Svi';
$lang['Who can see these photos?'] = 'Tko može pregledavati ove slike?';
$lang['The websize maximum width must be a number between %d and %d'] = 'Najveća širina web prozora mora biti broj između %d i %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'Najveća visina web prozora mora biti broj između %d i %d';
$lang['The websize image quality must be a number between %d and %d'] = 'Kakvoća slike u web prozoru mora biti broj između %d i %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'Najveća širina poveznih sličica mora biti broj između %d i %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'Najveća visina poveznih sličica mora biti broj između %d i %d';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'Kakvoća poveznih sličica mora biti broj između %d i %d';
$lang['Settings'] = 'Postavke';
$lang['Web size photo'] = 'Veličina slike na web stranici';
$lang['Resize'] = 'Pronijeni veličinu';
$lang['Maximum Width'] = 'Najveća Širina';
$lang['pixels'] = 'piksela';
$lang['Maximum Height'] = 'Najveća Visina';
$lang['Image Quality'] = 'Kakvoća slike';
$lang['Save Settings'] = 'Pohrani Postavke';
$lang['Your configuration settings are saved'] = 'Vaše postavke su pohranjene';
$lang['Active Themes'] = 'Aktivne Teme';
$lang['Add write access to the "%s" directory'] = 'Dodaj dozvolu upisa za "%s" mapu';
$lang['Administration Home'] = 'Upravna Ploča';
$lang['Change Admin Colors'] = 'Promijeni boje upravnog dijela';
$lang['Delete this theme'] = 'izbriši ovu temu';
$lang['Directory does not exist'] = 'Mapa ne postoji';
$lang['Download,'] = 'Preuzmi,';
$lang['FTP + Synchronization'] = 'FTP + Usklađivanje';
$lang['Get Support on Piwigo Forum'] = 'Potražite pomoć u Piwigo forumu';
$lang['Help Me'] = 'Pomozite Mi';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Ova tema se ne može postaviti, jer nedostaje nadređena tema: %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Ova tema se ne može brisati, zbog drugih tema ovisnih o njoj: %s';
$lang['Inactive Themes'] = 'Nekorištene teme';
$lang['Install on your computer,'] = 'Ugradite na svoje računalo,';
$lang['Make this theme available to users'] = 'Očinite ovu teme dostumon korisnicima';
$lang['Page end'] = 'Kraj stranice';
$lang['Piwigo Uploader'] = 'Piwigo Prebacivač';
$lang['Read Piwigo Documentation'] = 'Pročitajte Piwigo Dokimentaciju';
$lang['Start pLoader and add your photos.'] = 'Pokreni pLoader i dodajte svoje slike.';
$lang['Switch to clear or dark colors for administration'] = 'Prebaci na svijetle ili tamne boje za upravljanje';
$lang['Theme has been successfully installed'] = 'Tema je uspješno ugrađena';
$lang['Visit Gallery'] = 'Posjetite galeriju';
$lang['Visit Piwigo project website'] = 'Posjetite web stranicu Piwigo projekta';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader znači <em>Piwigo Uploader</em>. Sa vašeg računala, pLoader priprema vaše slike i prebacuje ih u vašu Piwigo galeriju.';
$lang['Guest Settings'] = 'Postavke Gost računa';
$lang['Main Page'] = 'Glavna stranica';
$lang['Photo Page'] = 'Stranica Slika';
$lang['Activate Navigation Bar'] = 'Uključiti navigacijsku traku';
$lang['Activate Navigation Thumbnails'] = 'Uključiti navigacijske povezne sličice';
$lang['Activate icon "%s"'] = 'Uključiti ikonu "%s"';
$lang['Activate field "%s"'] = 'Uključiti polje "%s"';
$lang['Photo Properties'] = 'Svojstva slika';
$lang['Allow user customization'] = 'Dozvoliti korisničku prilagodbu';
$lang['Languages'] = 'Jezici';
$lang['Installed Languages'] = 'Ugrađeni Jezici';
$lang['Add New Language'] = 'Dodaj Novi Jezik';
$lang['Language has been successfully installed'] = 'Jezik uspješno ugrađen';
$lang['Select:'] = 'Odaberi:';
$lang['None'] = 'Nijedan';
$lang['Invert'] = 'Obrnuto';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Nemoguće je isključiti ovu temu, potrebna je najmanje jedna tema.';
$lang['Webmaster status is required.'] = 'Potrebne su Webmaster ovlasti.';
$lang['Bound Theme'] = 'Prikači Temu';
$lang['Allow rating'] = 'Dozvoli ocjenjivanje';
$lang['Select at least one comment'] = 'Odaberite najmanje jedan komentar';
$lang['Active Plugins'] = 'Uključeni Dodaci';
$lang['Inactive Plugins'] = 'Isključeni Dodaci';
$lang['Missing Plugins'] = 'Nedostajući Dodaci';
$lang['Uninstalled Plugins'] = 'Uklonjeni Dodaci';
$lang['By %s'] = 'Po %s';
$lang['Visit plugin site'] = 'Posjetite strancu dodataka';
$lang['Active Languages'] = 'Uključeni Jezici';
$lang['Delete this language'] = 'Izbrišite ovaj jezik';
$lang['Forbid this language to users'] = 'Zabranite ovaj jezik korisnicima';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Nemoguće je isključenje ovog jezika, prvo postavite neki drugi jezik kao pretpostavljen.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Nemoguće je isključenje ovog jezika, trebate imati najmanje jedan jezik.';
$lang['Inactive Languages'] = 'Isključeni Jezici';
$lang['Make this language available to users'] = 'Učinite ovaj jezik dostupnim korisnicima';
$lang['Set as default language for unregistered and new users'] = 'Postavi kao pretpostavljen jezik za nove i nepoznate korisnike';
$lang['Add Photos'] = 'Dodaj Slike';
$lang['Download'] = 'Preuzmi';
$lang['The following tag was deleted'] = 'Slijedeći tag je izbrisan';
$lang['Miscellaneous'] = 'Razno';
$lang['Virtual Links'] = 'Prividne Poveznice';
$lang['There is no other language available.'] = 'Neme dostupnih drugih jezika.';
$lang['There is no other plugin available.'] = 'Nema dostupnih drugih dodataka.';
$lang['There is no other theme available.'] = 'Nema dostupnih drugih tema.';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Vrijeme izvršenja je isteklo, postupak se mora nastaviti [Procijenjeno vrijeme: %d sekunda].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Vrijeme izvršenja je premašeno, postupak se mora nastaviti [Procijenjeno vrijeme: %d sekunda].';
$lang['By rank'] = 'Po poretku';
$lang['Manual order'] = 'Ručni poredak';
$lang['Add another set of photos'] = 'Dodaj još jedan skup slika';
$lang['Path'] = 'Putanja';
$lang['Order of menubar items has been updated successfully.'] = 'Redoslijed  stavki izborne trake je uspješno obnovljen.';
$lang['This theme was not designed to be directly activated'] = 'Ova tema nije zamišljena za neposrednu postavu'; 
$lang['Menu Management'] = 'Izbornik';
$lang['Action'] = 'Akcija';
$lang['Add a filter'] = 'Dodaj filter';
$lang['Album photos associated to the following albums: %s'] = 'Fotografije vezane uz sljedeće albume: %s';
$lang['Albums automatically sorted'] = 'Automatski poredak albuma';
$lang['All %d photos are selected'] = 'Označeno %d fotografija';
$lang['Apply action'] = 'Potvrdi akciju';
$lang['automatic order'] = 'automatski poredak';
$lang['Batch Manager'] = 'Skupno uređivanje';
$lang['Choose an action'] = 'Odaberi akciju';
$lang['Delete orphan tags'] = 'Briši nekorištene oznake';
$lang['delete photo'] = 'briši fotografiju';
$lang['duplicates'] = 'duplići';
$lang['Error on file "%s" : %s'] = 'Greška na datoteci "%s" : %s';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif ekstenzija nije dostupna, administrator bi trebao onemogućiti korištenje exif-a';
$lang['Failed to write file to disk'] = 'Nije uspjelo zapisivanje na disk';
$lang['File upload stopped by extension'] = 'Upload datoteke je zaustavljen od strane ekstenzije';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'Vrijednost upload_max_filesize (%sB) u vašoj php.ini datoteci je veća od post_max_size (%sB), trebali biste podesiti te postavke';
$lang['include child albums'] = 'uključi podalbume';
$lang['Keep high definition'] = 'Zadrži visoku kvalitetu';
$lang['last import'] = 'zadnji import';
$lang['manual order'] = 'ručni poredak';
$lang['%d of %d photos selected'] = 'označeno %d od %d fotografija';
$lang['Missing a temporary folder'] = 'Nedostaje privremena mapa';
$lang['new'] = 'novo';
$lang['No file was uploaded'] = 'Datoteka nije poslana';
$lang['No photo in the current set.'] = 'U trenutnoj grupi nema fotografija.';
$lang['No photo selected, %d photos in current set'] = 'Fotografije nisu označene, %d fotografija u trenutnoj grupi';
$lang['No photo selected, no action possible.'] = 'Nijedna fotografija nije označena.';
$lang['No results'] = 'Nema rezultata';
$lang['on the %d selected photos'] = 'na %d označenih fotografija';
$lang['Orphan tags deleted'] = 'Nekorištene oznake su izbrisane';
$lang['Pending Comments'] = 'Neriješeni komentari';
$lang['predefined filter'] = 'predefinirani filter';
$lang['Refresh photo set'] = 'Osvježi grupu fotografija';
$lang['Remove all filters'] = 'Ukloni sve filtre';
$lang['remove author'] = 'ukloni autora';
$lang['remove creation date'] = 'ukloni datum nastanka';
$lang['Remove from caddie'] = 'Ukloni iz caddie';
$lang['remove this filter'] = 'ukloni ovaj filter';
$lang['remove title'] = 'ukloni naslov';
$lang['Searching...'] = 'Tražim ...';
$lang['Selection'] = 'Odabir';
$lang['Set author'] = 'Postavi autora';
$lang['Set creation date'] = 'Postavi datum nastanka';
$lang['Set title'] = 'Postavi naslov';
$lang['The high definition image quality must be a number between %d and %d'] = 'Kvaliteta slike visoke razlučivosti mora biti broj između %d i %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'Maksimalna visina slike visoke razlučivosti mora biti broj između %d i %d';
$lang['The high definition maximum width must be a number between %d and %d'] = 'Maksimalna širina slike visoke razlučivosti mora biti broj između %d i %d';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Veličina poslane datoteke prelazi MAX_FILE_SIZE postavku definiranu unutar HTML obrasca';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Veličina poslane datoteke prelazi uload_max_filesize postavku u php.ini: %sB';
$lang['The uploaded file was only partially uploaded'] = 'Poslana datoteka je djelomično upload-ana';
$lang['Rate'] = 'Ocjena';
$lang['Average rate'] = 'Prosječna ocjena';
$lang['An error has occured during upgrade.'] = 'Došlo je do greške tijekon postupka nadogradnje.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Greška se dogodila tijekom izlučivanja. Molimo provjerite upisne dozvole vaše piwigo postave.<br><a href="%s">Kliknite za prikaz dnevnika greške</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo ne može dohvatiti zapis nadogradnje sa poslužitelja';
$lang['Dump Database'] = 'Isprazni bazu podataka';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Uključi povijest posjeta (Pozor: memorijsko ograničenje poslužitelja može biti premašeno)';
$lang['Unable to write new local directory.'] = 'Nemoguć upis u novu lokalnu mapu.';
$lang['Unable to send template directory.'] = 'Nemoguće slanje mape predložaka.';
$lang['Unable to dump database.'] = 'Nemoguće pražnjenje baze podataka.';
$lang['Save Template Directory'] = 'Sačuvaj mapu predložaka';
$lang['Some themes and plugins may be not available yet.'] = 'Neke teme i dodaci možda nisu još dostupni.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Možete nadograditi Piwigo na inačicu %s neposredno, bez nadograđivanja na inačicu Piwigo %s (preporučeno).';
$lang['Update to Piwigo %s'] = 'Nadogradnja na Piwigo inačicu %s';
$lang['Two updates are available'] = 'Dvije su nadogradnje dostupne';
$lang['This is a minor update, with only bug corrections.'] = 'Ovo je manja nadogradnja, samo popravke grešeaka.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Ovo je veća nadogradnja, sa <a href="%s">novim uzbudljivim mogućnostima</a>.';
$lang['Update in progress... Please wait.'] = 'Nadogradnja u tijeku... Molimo sačekajte.';
$lang['Activate icon "new" next to albums and pictures'] = 'Aktivirajte sličicu "Novo" pored albuma i slika';
$lang['Add a criteria'] = 'Dodaj uvjet';
$lang['Deactivate all'] = 'Sve deaktiviraj';
$lang['Default photos order'] = 'Zadani poredak fotografija';
$lang['Restore'] = 'Vrati';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Vrati zadane postavke. Postojeće postve dodataka će se izgubiti!';
$lang['Show menubar'] = 'Prikaži liniju izbornika';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Poslana datoteka prelazi post_max_size direktivu u php.ini: %sB';
$lang['The whole page'] = 'Cijela stranica';
$lang['The whole set'] = 'Cijeli set';
$lang['Type here the author name'] = 'Unesi ime autora';
$lang['Type here the title'] = 'Unesi naslov';
$lang['Type in a search term'] = 'Traži ..';
$lang['Unknown upload error'] = 'Nepoznata greška prilikom slanja datoteke';

?>